@@ -1,5 +1,5 @@
 /*
- *	$Id: diskdump.h,v 1.2 2002/04/04 13:29:45 solyga Exp $
+ *	$Id: diskdump.h,v 1.4 2002/10/16 15:38:53 solyga Exp $
  */
 
 #undef	DEBUG
@@ -40,21 +40,21 @@
 #include <sys/stat.h>		/* open() */
 #include <fcntl.h>		/* open(), O_RDONLY */
 
-#define	STD_CHANNEL	stdout
+#define	VERBOSE_CHANNEL	stderr
 #define	HELP_CHANNEL	stdout
 #define	ERROR_CHANNEL	stderr
 #define	VERSION_CHANNEL	stdout
-#define	INFO_CHANNEL	stderr
 #define	DEBUG_CHANNEL	stderr
 
 #define	BUFFER_SIZE	0x1000
+#define	DIVIDERS	" \t,;:"
 
 #define	RETVAL_OK	0
 #define	RETVAL_ERROR	1
 #define	RETVAL_BUG	2
 
-#define	VERSION_NUMBER		"0.40.01"
-#define	DATE_OF_LAST_MOD	"2002-04-04"
+#define	VERSION_NUMBER		"0.40.02"
+#define	DATE_OF_LAST_MOD	"2002-10-16"
 #define	MY_EMAIL_ADDRESS	"Steffen Solyga <solyga@absinth.net>"
 
 #define	MIN(A,B)	( (A) < (B) ? (A) : (B) )
